@@ -7,7 +7,7 @@ Main Wammu window
 __author__ = 'Michal Čihař'
 __email__ = 'michal@cihar.com'
 __license__ = '''
-Copyright © 2003 - 2009 Michal Čihař
+Copyright © 2003 - 2010 Michal Čihař
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License version 2 as published by
@@ -78,6 +78,7 @@ import Wammu.TalkbackDialog
 import Wammu.WammuSettings
 import Wammu.SMSExport
 import Wammu.SMSXML
+import Wammu.ContactsXML
 from Wammu.Locales import StrConv, ConsoleStrConv
 
 TALKBACK_COUNT = 30
@@ -315,6 +316,8 @@ class WammuFrame(wx.Frame):
         menu3.Append(340, _('&Todos'), _('Retrieve todos.'))
         menu3.AppendSeparator()
         menu3.Append(350, _('Calenda&r'), _('Retrieve calendar events.'))
+        menu3.AppendSeparator()
+        menu3.Append(399, _('A&ll'), _('Retrieve everything above.'))
         # Add menu to the menu bar
         self.menuBar.Append(menu3, _('&Retrieve'))
 
@@ -329,11 +332,12 @@ class WammuFrame(wx.Frame):
         menu5 = wx.Menu()
         menu5.Append(501, _('&Save'), _('Save currently retrieved data (except messages) to backup.'))
         menu5.Append(502, _('S&ave messages'), _('Save currently retrieved messages to backup.'))
-        menu5.Append(503, _('&Import'), _('Import data from backup to phone.'))
-        menu5.Append(504, _('I&mport messages'), _('Import messages from backup to phone.'))
+        menu5.Append(503, _('&Import to phone'), _('Import data from backup to phone.'))
+        menu5.Append(504, _('I&mport messages to phone'), _('Import messages from backup to phone.'))
         menu5.AppendSeparator()
         menu5.Append(510, _('Export messages to &emails'), _('Export messages to emails in storage you choose.'))
         menu5.Append(511, _('Export messages to &XML'), _('Export messages to XML file you choose.'))
+        menu5.Append(512, _('Export &contacts to XML'), _('Export contacts to XML file you choose.'))
         # Add menu to the menu bar
         self.menuBar.Append(menu5, _('&Backups'))
 
@@ -377,6 +381,7 @@ class WammuFrame(wx.Frame):
         wx.EVT_MENU(self, 330, self.ShowMessages)
         wx.EVT_MENU(self, 340, self.ShowTodos)
         wx.EVT_MENU(self, 350, self.ShowCalendar)
+        wx.EVT_MENU(self, 399, self.GetAll)
 
         wx.EVT_MENU(self, 401, self.NewContact)
         wx.EVT_MENU(self, 402, self.NewCalendar)
@@ -389,6 +394,7 @@ class WammuFrame(wx.Frame):
         wx.EVT_MENU(self, 504, self.ImportSMS)
         wx.EVT_MENU(self, 510, self.SMSToMails)
         wx.EVT_MENU(self, 511, self.SMSToXML)
+        wx.EVT_MENU(self, 512, self.ContactsToXML)
 
 
         wx.EVT_MENU(self, 1001, self.Website)
@@ -591,6 +597,7 @@ class WammuFrame(wx.Frame):
         if self.cfg.Read('/Wammu/TaskBarIcon') != 'yes':
             if self.tbicon is not None:
                 self.tbicon.Destroy()
+                self.tbicon = None
             return
         if self.tbicon is not None:
             # Nothing to do
@@ -781,6 +788,8 @@ class WammuFrame(wx.Frame):
 
         mb.Enable(350, enable);
 
+        mb.Enable(399, enable);
+
         mb.Enable(401, enable);
         mb.Enable(402, enable);
         mb.Enable(403, enable);
@@ -793,6 +802,7 @@ class WammuFrame(wx.Frame):
 
         mb.Enable(510, enable);
         mb.Enable(511, enable);
+        mb.Enable(512, enable);
 
     def ActivateView(self, k1, k2):
         self.tree.SelectItem(self.treei[k1][k2])
@@ -839,7 +849,7 @@ class WammuFrame(wx.Frame):
         if self.connected:
             connection_settings = {
                 'Connection': self.cfg.Read('/Gammu/Connection'),
-                'LockDevice': self.cfg.Read('/Gammu/LockDevice'),
+                'LockDevice': self.cfg.ReadBool('/Gammu/LockDevice'),
                 'Device': self.cfg.Read('/Gammu/Device'),
                 'Model': self.cfg.Read('/Gammu/Model')
             }
@@ -849,7 +859,7 @@ class WammuFrame(wx.Frame):
             if self.connected:
                 connection_settings_new = {
                     'Connection': self.cfg.Read('/Gammu/Connection'),
-                    'LockDevice': self.cfg.Read('/Gammu/LockDevice'),
+                    'LockDevice': self.cfg.ReadBool('/Gammu/LockDevice'),
                     'Device': self.cfg.Read('/Gammu/Device'),
                     'Model': self.cfg.Read('/Gammu/Model')
                 }
@@ -909,8 +919,12 @@ class WammuFrame(wx.Frame):
         self.Destroy()
 
     def ShowError(self, info):
+        try:
+            gammu_config = self.gammu_config
+        except AttributeError:
+            gammu_config = Noe
         evt = Wammu.Events.ShowMessageEvent(
-            message = Wammu.Utils.FormatError(_('Error while communicating with phone'), info),
+            message = Wammu.Utils.FormatError(_('Error while communicating with phone'), info, gammu_config = gammu_config),
             title = _('Error Occured'),
             errortype = 'gammu',
             type = wx.ICON_ERROR)
@@ -989,7 +1003,7 @@ class WammuFrame(wx.Frame):
                 (_('Folder'), StrConv(v['SMS'][0]['Folder'])),
                 (_('Memory'), StrConv(v['SMS'][0]['Memory'])),
                 (_('SMSC'), Wammu.Utils.GetNumberLink([] + self.values['contact']['ME'] + self.values['contact']['SM'], v['SMS'][0]['SMSC']['Number'])),
-                (_('State'), StrConv(v['State']))]
+                (_('Status'), StrConv(v['State']))]
             if v['Name'] != '':
                 data.append((_('Name'), StrConv(v['Name'])))
             data.append((Wammu.MessageDisplay.SmsToHtml(self.cfg, v),))
@@ -1259,6 +1273,8 @@ class WammuFrame(wx.Frame):
             return
         if self.type[0] == 'contact':
             self.EditContact(evt.data)
+        elif self.type[0] == 'call' and evt.data['Location'] == 0:
+            self.EditContact(evt.data)
         elif self.type[0] == 'calendar':
             self.EditCalendar(evt.data)
         elif self.type[0] == 'todo':
@@ -1357,6 +1373,9 @@ class WammuFrame(wx.Frame):
             self.values['contact']['SM']
         Wammu.SMSXML.SMSExportXML(self, messages, contacts)
 
+    def ContactsToXML(self, evt):
+        Wammu.ContactsXML.ContactsExportXML(self, self.values['contact']['SM'], self.values['contact']['ME'])
+
     def SelectBackupFile(self, type, save = True, data = False):
         wildcard = ''
         if type == 'message':
@@ -1500,7 +1519,6 @@ class WammuFrame(wx.Frame):
                 if datatype == 'message':
                     smsl = []
                     for v in backup:
-                        v['Folder'] = 2 # FIXME: this should be configurable
                         v['SMSC']['Location'] = 1
                         (v['Location'], v['Folder']) = self.sm.AddSMS(v)
                         # reread entry (it doesn't have to contain exactly same data as entered, it depends on phone features)
@@ -2004,6 +2022,59 @@ class WammuFrame(wx.Frame):
         self.nextfun = self.ActivateView
         self.nextarg = ('calendar', '  ')
 
+    #
+    # Get everything
+    #
+
+    def GetAll(self, event):
+        self.ShowProgress(_('Reading phone information'))
+        Wammu.Info.GetInfo(self, self.sm).start()
+        self.nextfun = self.GetAll2
+        self.nextarg = ()
+
+    def GetAll2(self):
+        self.GetContactsType('SM')
+        self.nextfun = self.GetAll3
+        self.nextarg = ()
+
+    def GetAll3(self):
+        self.GetContactsType('ME')
+        self.nextfun = self.GetAll4
+        self.nextarg = ()
+
+    def GetAll4(self):
+        self.GetCallsType('MC')
+        self.nextfun = self.GetAll5
+        self.nextarg = ()
+
+    def GetAll5(self):
+        self.GetCallsType('DC')
+        self.nextfun = self.GetAll6
+        self.nextarg = ()
+
+    def GetAll6(self):
+        self.GetCallsType('RC')
+        self.nextfun = self.GetAll7
+        self.nextarg = ()
+
+    def GetAll7(self):
+        self.ShowProgress(_('Reading messages'))
+        Wammu.Message.GetMessage(self, self.sm).start()
+        self.nextfun = self.GetAll8
+        self.nextarg = ()
+
+    def GetAll8(self):
+        self.ShowProgress(_('Reading todos'))
+        Wammu.Todo.GetTodo(self, self.sm).start()
+        self.nextfun = self.GetAll9
+        self.nextarg = ()
+
+    def GetAll9(self):
+        self.ShowProgress(_('Reading calendar'))
+        Wammu.Calendar.GetCalendar(self, self.sm).start()
+        self.nextfun = self.ActivateView
+        self.nextarg = ('info', '  ')
+
     #
     # Time
     #
@@ -2086,18 +2157,23 @@ class WammuFrame(wx.Frame):
                 wx.OK | wx.ICON_ERROR).ShowModal()
             return
         cfg = {
-            'StartInfo': self.cfg.Read('/Gammu/StartInfo'),
-            'UseGlobalDebugFile': 1,
+            'StartInfo': self.cfg.ReadBool('/Gammu/StartInfo'),
+            'UseGlobalDebugFile': True,
             'DebugFile': None, # Set on other place
-            'SyncTime': self.cfg.Read('/Gammu/SyncTime'),
+            'SyncTime': self.cfg.ReadBool('/Gammu/SyncTime'),
             'Connection': config['Connection'],
-            'LockDevice': self.cfg.Read('/Gammu/LockDevice'),
+            'LockDevice': self.cfg.ReadBool('/Gammu/LockDevice'),
             'DebugLevel': 'textalldate', # Set on other place
             'Device': config['Device'],
             'Model': config['Model'],
             }
-        if cfg['Model'] == 'auto':
-            cfg['Model'] = ''
+
+        # Store configuration for error handling
+        self.gammu_config = cfg
+
+        # Compatibility with old Gammu versions
+        cfg = Wammu.Utils.CompatConfig(cfg)
+
         self.sm.SetConfig(0, cfg)
         try:
             self.sm.Init()
@@ -2139,6 +2215,20 @@ class WammuFrame(wx.Frame):
             except gammu.GSMError, val:
                 pass
 
+        # Check for PIN
+        if self.connected:
+            try:
+                code = self.sm.GetSecurityStatus()
+            except gammu.GSMError:
+                code = None
+            if code is not None:
+                dlg = wx.PasswordEntryDialog(self,
+                    _('Please enter %s code:') % code,
+                    _('Phone asks for security code'))
+                if dlg.ShowModal() == wx.ID_OK:
+                    self.sm.EnterSecurityCode(code, dlg.GetValue())
+
+
     def DBUSActionCallback(self, id, action):
         '''
         Called when user does something on notification.
@@ -2156,10 +2246,13 @@ class WammuFrame(wx.Frame):
         Performs D-Bus notification if available.
         '''
         if self.dbus_notify is not None:
-            self.last_dbus_id = self.dbus_notify.Notify(
-                    'Wammu', self.last_dbus_id, 'wammu',
-                    title, message, actions, {}, -1)
-
+            try:
+                self.last_dbus_id = self.dbus_notify.Notify(
+                        'Wammu', self.last_dbus_id, 'wammu',
+                        title, message, actions, {}, -1)
+            except dbus.DBusException:
+                self.dbus_notify = None
+                self.last_dbus_id = 0
 
     def IncomingEvent(self, sm, type, data):
         '''
@@ -2206,6 +2299,13 @@ class WammuFrame(wx.Frame):
         wx.PostEvent(self.searchlog, evt)
 
     def SearchPhone(self, evt = None):
+        if self.connected:
+            wx.MessageDialog(self,
+                _('Searching for phone can not be performed while you are connected to phone, please disconnect first.'),
+                _('You are connected to phone!'),
+                wx.OK | wx.ICON_ERROR).ShowModal()
+            return
+
         index = self.cfg.gammu.FirstFree()
         result = Wammu.PhoneWizard.RunConfigureWizard(self, index)
         if result is not None:
@@ -2222,7 +2322,7 @@ class WammuFrame(wx.Frame):
         Wammu.Webbrowser.Open("http://%swammu.eu/support/?version=%s" % (Wammu.Utils.GetWebsiteLang(), Wammu.__version__))
 
     def ReportBug(self, evt = None):
-        Wammu.Webbrowser.Open("http://bugs.cihar.com/set_project.php?ref=bug_report_page.php&project_id=1")
+        Wammu.Webbrowser.Open("https://github.com/gammu/gammu/issues")
 
     def PhoneDB(self, evt = None):
         Wammu.Webbrowser.Open("http://%swammu.eu/phones/" % Wammu.Utils.GetWebsiteLang())
